@@ -6,7 +6,7 @@ use Stenciller::Wrap;
 
 package Stenciller;
 
-our $VERSION = '0.1208'; # VERSION:
+our $VERSION = '0.1209'; # VERSION:
 # PODCLASSNAME:
 # ABSTRACT: Transforms a flat file format to different output
 
@@ -32,13 +32,15 @@ Stenciller - Transforms a flat file format to different output
 
 =head1 VERSION
 
-Version 0.1208, released 2015-02-08.
+Version 0.1209, released 2015-02-09.
+
+
 
 =head1 SYNOPSIS
 
     use Stenciller;
     my $stenciller = Stenciller->new(filepath => 't/corpus/test-1.stencil');
-    my $content = $stenciller->transform('ToUnparsedText');
+    my $content = $stenciller->transform(plugin_name => 'ToUnparsedText');
 
 =head1 DESCRIPTION
 
@@ -59,8 +61,6 @@ Stenciller reads a special fileformat and provides a way to convert the content
 This is the basic layout. A stencil ends when a new stencil block is discovered (there is no set limit to the number of stencils in a file). The (optional) hash is for settings. Each stencil has five parts: C<before_input>, C<input>, C<between>, C<output> and C<after_output>. In addition to this
 there is a header before the first stencil.
 
-
-
 =head1 ATTRIBUTES
 
 
@@ -176,6 +176,17 @@ there is a header before the first stencil.
 
 <tr style="vertical-align: top;"><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8eee8;">Named parameters</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8eee8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8eee8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8eee8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8eee8;">&#160;</td></tr>
 <tr style="vertical-align: top;">
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>plugin_name =&gt; $value</code>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">required</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  border-bottom: 1px solid #eee;"></td>
+<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Plugin to read contents with.</td>
+</tr>
+<tr style="vertical-align: top;">
 <td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>constructor_args =&gt; $value</code>
 
 </td>
@@ -189,17 +200,6 @@ there is a header before the first stencil.
 <td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Constructor arguments for the plugin.</td>
 </tr>
 <tr style="vertical-align: top;">
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>plugin_name =&gt; $value</code>
-
-</td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
-
-</td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">optional, <span style="color: #999;">no default</span></td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  border-bottom: 1px solid #eee;"></td>
-<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Plugin to read contents with.</td>
-</tr>
-<tr style="vertical-align: top;">
 <td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>transform_args =&gt; $value</code>
 
 </td>
@@ -217,7 +217,7 @@ there is a header before the first stencil.
 <td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
 
 </td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td>
-<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Returns the transformed content.</td>
+<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">The transformed content.</td>
 </tr>
 </table>
 
