@@ -2,7 +2,7 @@ use Stenciller::Standard;
 use Stenciller::Stencil;
 use strict;
 use warnings;
-our $VERSION = '0.1208'; # VERSION:
+our $VERSION = '0.1209'; # VERSION:
 # PODNAME: Stenciller::Wrap
 
 use Module::Pluggable search_path => ['Stenciller::Plugin'];
@@ -82,10 +82,10 @@ class Stenciller::Wrap using Moose with Stenciller::Utils {
         return !!$count || 0;
     }
 
-    method transform(Str :$plugin_name           does doc('Plugin to read contents with.'),
+    method transform(Str :$plugin_name!          does doc('Plugin to read contents with.'),
                      HashRef :$constructor_args? does doc('Constructor arguments for the plugin.')     = {},
                      HashRef :$transform_args?   does doc('Settings for the specific transformation.') = {}, ...
-                 --> Str     but assumed         does doc('Returns the transformed content.')
+                 --> Str     but assumed         does doc('The transformed content.')
     ) {
 
         my $plugin_class = "Stenciller::Plugin::$plugin_name";
@@ -197,7 +197,7 @@ Stenciller::Wrap
 
 =head1 VERSION
 
-Version 0.1208, released 2015-02-08.
+Version 0.1209, released 2015-02-09.
 
 =head1 SOURCE
 
